bayespy.nodes.SwitchingGaussianMarkovChain.add_plate_axis
=========================================================

.. currentmodule:: bayespy.nodes

.. automethod:: SwitchingGaussianMarkovChain.add_plate_axis